pub struct IconButtonProps {
pub glyph: String,
pub label: String,
pub variant: IconButtonVariant,
pub disabled: bool,
pub pressed: bool,
}Expand description
Props for the IconButton component.
Required Props
- glyph:
impl Into<String>- Single glyph rendered as the button label.
- label:
impl Into<String>- Accessible label — required for screen readers since the visible content is just a glyph.
Optional Props
- variant:
IconButtonVariant - disabled:
bool - pressed:
bool
Fields
glyph: StringSingle glyph rendered as the button label.
label: StringAccessible label — required for screen readers since the visible content is just a glyph.
variant: IconButtonVariantdisabled: boolpressed: boolImplementations
Sourceimpl IconButtonProps
impl IconButtonProps
Sourcepub fn builder() -> IconButtonPropsBuilder<((), (), (), (), ())>
pub fn builder() -> IconButtonPropsBuilder<((), (), (), (), ())>
Create a builder for building IconButtonProps.
On the builder, call .glyph(...), .label(...), .variant(...)(optional), .disabled(...)(optional), .pressed(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of IconButtonProps.