pub enum DevicePickerState {
Populated,
Empty,
PermissionNeeded,
}Expand description
State of the picker beyond a normal device list.
Variants
Populated
One or more devices available.
Empty
No devices detected.
PermissionNeeded
Permission has not been granted by the user yet.