pub struct DevicePickerMenuProps {
pub kind: CaptureSourceKind,
pub devices: Vec<DeviceOptionView>,
pub state: DevicePickerState,
}Expand description
Props for the DevicePickerMenu component.
Required Props
- kind:
CaptureSourceKind- Whether this picker is for the camera or microphone slot.
- devices:
Vec<DeviceOptionView>- Device list — typically
fixtures::devices::sample_camera_options(). Ignored whenstate != Populated.
- Device list — typically
Optional Props
- state:
DevicePickerState- Empty / permission-needed override.
Fields
kind: CaptureSourceKindWhether this picker is for the camera or microphone slot.
devices: Vec<DeviceOptionView>Device list — typically fixtures::devices::sample_camera_options().
Ignored when state != Populated.
state: DevicePickerStateEmpty / permission-needed override.
Implementations