pub struct StatusBarProps {
pub fps: f32,
pub encoder: String,
pub file_bytes: u64,
pub kind: StatusKind,
pub detail: String,
}Expand description
Props for the StatusBar component.
Optional Props
- fps:
f32- Renderer FPS, formatted as a whole number.
- encoder:
impl Into<String>- Encoder one-line status (e.g.
"H.264 · 9.4 Mbps").
- Encoder one-line status (e.g.
- file_bytes:
u64- File size on disk for the active recording, in bytes.
- kind:
StatusKind- Right-hand health pill kind.
- detail:
impl Into<String>- Free-text detail next to the pill (e.g. error message).
Fields
fps: f32Renderer FPS, formatted as a whole number.
encoder: StringEncoder one-line status (e.g. "H.264 · 9.4 Mbps").
file_bytes: u64File size on disk for the active recording, in bytes.
kind: StatusKindRight-hand health pill kind.
detail: StringFree-text detail next to the pill (e.g. error message).
Implementations
Sourceimpl StatusBarProps
impl StatusBarProps
Sourcepub fn builder() -> StatusBarPropsBuilder<((), (), (), (), ())>
pub fn builder() -> StatusBarPropsBuilder<((), (), (), (), ())>
Create a builder for building StatusBarProps.
On the builder, call .fps(...)(optional), .encoder(...)(optional), .file_bytes(...)(optional), .kind(...)(optional), .detail(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of StatusBarProps.