pub fn default_ui_fixtures() -> UiFixtureSetExpand description
Deterministic fixture bundle used by the contact sheet + the design-review chapter.
pub fn default_ui_fixtures() -> UiFixtureSetDeterministic fixture bundle used by the contact sheet + the design-review chapter.