pub fn sample_dope_sheet_dense() -> Vec<DopeSheetTrack>Expand description
Dense variant — adds a noisy effect track with twelve keyframes for the
dope-sheet-dense story.
pub fn sample_dope_sheet_dense() -> Vec<DopeSheetTrack>Dense variant — adds a noisy effect track with twelve keyframes for the
dope-sheet-dense story.