pub struct MenuRowProps {
pub kind: MenuRowKind,
pub leading: Option<Children>,
pub title: String,
pub subtitle: Option<String>,
pub badges: Vec<MenuBadgeView>,
pub trailing: Option<Children>,
}Expand description
Props for the MenuRow component.
Required Props
- title:
impl Into<String>- Primary row text.
Optional Props
- kind:
MenuRowKind - leading: [
Children]- Optional leading slot — an
IconTile/ avatar / small glyph.
- Optional leading slot — an
- subtitle:
impl Into<String>- Optional secondary text under the title.
- badges:
Vec<MenuBadgeView>- Badges rendered between the text and the trailing slot.
- trailing: [
Children]- Optional trailing slot — kbd shortcut, count, or chevron.
Fields
kind: MenuRowKindleading: Option<Children>Optional leading slot — an IconTile / avatar / small glyph.
title: StringPrimary row text.
subtitle: Option<String>Optional secondary text under the title.
badges: Vec<MenuBadgeView>Badges rendered between the text and the trailing slot.
trailing: Option<Children>Optional trailing slot — kbd shortcut, count, or chevron.
Implementations
Sourceimpl MenuRowProps
impl MenuRowProps
Sourcepub fn builder() -> MenuRowPropsBuilder<((), (), (), (), (), ())>
pub fn builder() -> MenuRowPropsBuilder<((), (), (), (), (), ())>
Create a builder for building MenuRowProps.
On the builder, call .kind(...)(optional), .leading(...)(optional), .title(...), .subtitle(...)(optional), .badges(...)(optional), .trailing(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of MenuRowProps.