pub struct PopoverSurfaceProps {
pub placement: PopoverPlacement,
pub width_px: Option<u16>,
pub title: Option<String>,
pub description: Option<String>,
pub children: Children,
pub footer: Option<Children>,
}Expand description
Props for the PopoverSurface component.
Required Props
- children: [
Children]- Body content — typically a
MenuList.
- Body content — typically a
Optional Props
- placement:
PopoverPlacement- Where the popover should anchor — drives a
popover-<placement>class but no positioning math.
- Where the popover should anchor — drives a
- width_px:
u16- Width in CSS pixels.
Nonelets content size itself.
- Width in CSS pixels.
- title:
impl Into<String>- Optional title rendered above the content with a small subtitle.
- description:
impl Into<String>- Optional description under the title.
- footer: [
Children]- Optional bottom footer — primary action button or hint text.
Fields
placement: PopoverPlacementWhere the popover should anchor — drives a popover-<placement>
class but no positioning math.
width_px: Option<u16>Width in CSS pixels. None lets content size itself.
title: Option<String>Optional title rendered above the content with a small subtitle.
description: Option<String>Optional description under the title.
children: ChildrenBody content — typically a MenuList.
Optional bottom footer — primary action button or hint text.
Implementations
Sourceimpl PopoverSurfaceProps
impl PopoverSurfaceProps
Sourcepub fn builder() -> PopoverSurfacePropsBuilder<((), (), (), (), (), ())>
pub fn builder() -> PopoverSurfacePropsBuilder<((), (), (), (), (), ())>
Create a builder for building PopoverSurfaceProps.
On the builder, call .placement(...)(optional), .width_px(...)(optional), .title(...)(optional), .description(...)(optional), .children(...), .footer(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of PopoverSurfaceProps.