pub struct SavePanelProps {
pub view: SavePanelView,
pub on_change_folder: Option<Callback<()>>,
pub on_format_change: Option<Callback<SaveFormat>>,
pub on_discard: Option<Callback<()>>,
pub on_edit: Option<Callback<()>>,
pub on_export: Option<Callback<()>>,
pub on_reveal: Option<Callback<()>>,
pub on_done: Option<Callback<()>>,
}Expand description
Props for the SavePanel component.
The post-record Save panel.
Required Props
- view:
SavePanelView- View-model. The parent rebuilds this whenever the pending export, chosen format, busy flag, or saved path changes.
Optional Props
- on_change_folder:
impl Into<Callback<()>>- Change-folder click (Choosing state). Wired to the native folder picker.
- on_format_change:
impl Into<Callback<SaveFormat>>- Format-dropdown change (Choosing state). Receives the newly
selected
SaveFormat.
- Format-dropdown change (Choosing state). Receives the newly
selected
- on_discard:
impl Into<Callback<()>>- Discard click (Choosing state) — deletes the scratch.
- on_edit:
impl Into<Callback<()>>- Edit click (Choosing state) — save the recording and open it in the editor.
- on_export:
impl Into<Callback<()>>- Export click (Choosing state) — runs the move / transcode.
- on_reveal:
impl Into<Callback<()>>- Reveal-in-Finder click (Saved state).
- on_done:
impl Into<Callback<()>>- Done click (Saved state) — dismisses the panel.
Fields
view: SavePanelViewView-model. The parent rebuilds this whenever the pending export, chosen format, busy flag, or saved path changes.
on_change_folder: Option<Callback<()>>Change-folder click (Choosing state). Wired to the native folder picker.
on_format_change: Option<Callback<SaveFormat>>Format-dropdown change (Choosing state). Receives the newly
selected SaveFormat.
on_discard: Option<Callback<()>>Discard click (Choosing state) — deletes the scratch.
on_edit: Option<Callback<()>>Edit click (Choosing state) — save the recording and open it in the editor.
on_export: Option<Callback<()>>Export click (Choosing state) — runs the move / transcode.
on_reveal: Option<Callback<()>>Reveal-in-Finder click (Saved state).
on_done: Option<Callback<()>>Done click (Saved state) — dismisses the panel.
Implementations
Sourceimpl SavePanelProps
impl SavePanelProps
Sourcepub fn builder() -> SavePanelPropsBuilder<((), (), (), (), (), (), (), ())>
pub fn builder() -> SavePanelPropsBuilder<((), (), (), (), (), (), (), ())>
Create a builder for building SavePanelProps.
On the builder, call .view(...), .on_change_folder(...)(optional), .on_format_change(...)(optional), .on_discard(...)(optional), .on_edit(...)(optional), .on_export(...)(optional), .on_reveal(...)(optional), .on_done(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of SavePanelProps.